# Generated by roxygen2: do not edit by hand

S3method(plot,selection_simulation)
S3method(print,base_index)
S3method(print,dg_lpsi)
S3method(print,esim)
S3method(print,gesim)
S3method(print,gw_esim)
S3method(print,gw_lmsi)
S3method(print,lmsi)
S3method(print,mesim)
S3method(print,ppg_esim)
S3method(print,ppg_gesim)
S3method(print,resim)
S3method(print,rgesim)
S3method(print,selection_simulation)
S3method(print,smith_hazel)
S3method(summary,base_index)
S3method(summary,dg_lpsi)
S3method(summary,esim)
S3method(summary,gesim)
S3method(summary,gw_esim)
S3method(summary,mesim)
S3method(summary,ppg_esim)
S3method(summary,ppg_gesim)
S3method(summary,resim)
S3method(summary,rgesim)
S3method(summary,selection_simulation)
S3method(summary,smith_hazel)
export(base_index)
export(clgsi)
export(cppg_lgsi)
export(crlgsi)
export(dg_lpsi)
export(esim)
export(estimate_missing_values)
export(gen_advance)
export(gen_varcov)
export(genetic_genomic_varcov)
export(genomic_varcov)
export(gesim)
export(gw_esim)
export(gw_lmsi)
export(haldane_mapping)
export(inverse_haldane_mapping)
export(lgsi)
export(lmsi)
export(lpsi)
export(mean_performance)
export(mesim)
export(mlgsi)
export(mlpsi)
export(mppg_lgsi)
export(mppg_lpsi)
export(mrlgsi)
export(mrlpsi)
export(phen_varcov)
export(phenomic_genomic_varcov)
export(ppg_esim)
export(ppg_gesim)
export(ppg_lgsi)
export(ppg_lpsi)
export(predict_selection_score)
export(resim)
export(rgesim)
export(rlgsi)
export(rlpsi)
export(simulate_selection_cycles)
export(smith_hazel)
export(weight_mat)
importFrom(MASS,ginv)
importFrom(Rcpp,sourceCpp)
importFrom(graphics,legend)
importFrom(graphics,lines)
importFrom(stats,cor)
importFrom(stats,cov)
importFrom(stats,dnorm)
importFrom(stats,pf)
importFrom(stats,pnorm)
importFrom(stats,qnorm)
importFrom(stats,qt)
importFrom(stats,rbinom)
importFrom(stats,rnorm)
importFrom(stats,runif)
importFrom(stats,sd)
importFrom(stats,setNames)
importFrom(stats,var)
importFrom(utils,combn)
useDynLib(selection.index, .registration = TRUE)
